#
# spec file for package gimp
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global abiver 4
%global apiver 2.0

Name:           gimp
Version:        2.8.22
Release:        lp151.5.6.1
Summary:        The GNU Image Manipulation Program
License:        GPL-3.0+
Group:          Productivity/Graphics/Bitmap Editors
URL:            http://www.gimp.org/
Source:         http://download.gimp.org/pub/gimp/v2.8/%{name}-%{version}.tar.bz2
Source1:        macros.gimp
# openSUSE palette file
Source2:        openSUSE.gpl
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM gimp-gegl03-buildfix.patch bjorn.lie@gmail.com -- Port to gegl-03, patch taken from debian
Patch0:         gimp-gegl03-buildfix.patch
# PATCH-FIX-UPSTREAM gimp-bsc1073627-CVE-2017-17789.patch bsc#1073627 bgo#790849 CVE-2017-17789 zcjia@suse.com -- Fix heap buffer overflow in PSP importer
Patch1:         gimp-bsc1073627-CVE-2017-17789.patch
# PATCH-FIX-UPSTREAM gimp-fix-issue-3630-postscript-plugin-crashes.patch bsc#1161998 glgo#GNOME/GIMP#3630 qkzhu@suse.com -- Fix postscript plugin crashes
Patch2:         gimp-fix-issue-3630-postscript-plugin-crashes.patch
# PATCH-FIX-UPSTREAM gimp-CVE-2017-17787.patch bnc#1073628 CVE-2017-17787 qzhao@suse.com -- We have to check that strings being read at fixed length are properly nul-terminated.
Patch3:         gimp-CVE-2017-17787.patch
BuildRequires:  aalib-devel
BuildRequires:  alsa-devel >= 1.0.0
BuildRequires:  fdupes
BuildRequires:  fontconfig-devel >= 2.2.0
BuildRequires:  ghostscript-devel
# Explicitly needed, otherwise ghostscript-mini is used during the
# build, and it's not enough for gimp.
BuildRequires:  ghostscript-library
BuildRequires:  intltool >= 0.40.1
BuildRequires:  iso-codes-devel
BuildRequires:  libbz2-devel
BuildRequires:  libjasper-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libmng-devel
BuildRequires:  librsvg-devel >= 2.36.0
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  libwmf-devel >= 0.2.8
BuildRequires:  libxslt-tools
BuildRequires:  pkgconfig
BuildRequires:  python-gtk-devel >= 2.10.4
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(atk) >= 2.2.0
BuildRequires:  pkgconfig(babl) >= 0.1.10
BuildRequires:  pkgconfig(cairo) >= 1.10.2
BuildRequires:  pkgconfig(cairo-pdf) >= 1.10.2
BuildRequires:  pkgconfig(dbus-glib-1) >= 0.70
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.24.1
BuildRequires:  pkgconfig(gegl-0.3)
BuildRequires:  pkgconfig(glib-2.0) >= 2.30.2
BuildRequires:  pkgconfig(gtk+-2.0) >= 2.24.10
BuildRequires:  pkgconfig(gudev-1.0) >= 167
BuildRequires:  pkgconfig(lcms2) >= 2.2
BuildRequires:  pkgconfig(libexif) >= 0.6.15
BuildRequires:  pkgconfig(libpng) >= 1.2.37
BuildRequires:  pkgconfig(pango) >= 1.29.4
BuildRequires:  pkgconfig(poppler-glib) >= 0.12.4
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(zlib)
#%%if 0%{?suse_version} > 1320
#BuildRequires:  pkgconfig(libmypaint) >= 1.3
#%%endif
# Explicitly declare the libgimp versions for upgrade purposes
Requires:       libgimp-2_0-0 = %{version}
Requires:       libgimpui-2_0-0 = %{version}
Recommends:     %{name}-lang
Recommends:     %{name}-plugins-python = %{version}
Recommends:     iso-codes
Suggests:       AdobeICCProfiles
Suggests:       gimp-2.0-scanner-plugin
Obsoletes:      %{name}-help-browser

Provides:       gimp-2.0 = %{version}
Provides:       gimp(abi) = %{abiver}
Provides:       gimp(api) = %{apiver}

%description
The GIMP is an image composition and editing program, which can be
used for creating logos and other graphics for Web pages. The GIMP
offers many tools and filters, and provides a large image
manipulation toolbox, including channel operations and layers,
effects, subpixel imaging and antialiasing, and conversions, together
with multilevel undo. The GIMP offers a scripting facility, but many
of the included scripts rely on fonts that we cannot distribute.

%package -n libgimp-2_0-0
Summary:        The GNU Image Manipulation Program - Libraries
Group:          System/Libraries

%description -n libgimp-2_0-0
The GIMP is an image composition and editing program. GIMP offers
many tools and filters, and provides a large image manipulation
toolbox and scripting.

This package provides GIMP libraries.

%package -n libgimpui-2_0-0
Summary:        The GNU Image Manipulation Program - UI Libraries
Group:          System/Libraries

%description -n libgimpui-2_0-0
The GIMP is an image composition and editing program. GIMP offers
many tools and filters, and provides a large image manipulation
toolbox and scripting.

This package provides GIMP UI libraries.

%package plugins-python
Summary:        The GNU Image Manipulation Program - python-gtk based plugins
Group:          Productivity/Graphics/Bitmap Editors
Requires:       %{name} = %{version}
Requires:       python-gtk
Supplements:    %{name}
Provides:       gimp-2.0-plugins-python = %{version}
Obsoletes:      gimp-unstable-plugins-python < 2.6.0
# For update from <= 10.3 and SLED 10:
Provides:       %{name}:%{_libdir}/gimp/2.0/plug-ins/pyconsole.py = %{version}

%description plugins-python
The GIMP is an image composition and editing program. GIMP offers
many tools and filters, and provides a large image manipulation
toolbox and scripting.

%package plugin-aa
Summary:        The GNU Image Manipulation Program -- ASCII-Art output plugin
Group:          Productivity/Graphics/Bitmap Editors
Requires:       %{name} = %{version}
# Let's trigger automatic installation if the user already has libaa installed.
Supplements:    packageand(%{name}:libaa1)

%description plugin-aa
The GIMP is an image composition and editing program. GIMP offers
many tools and filters, and provides a large image manipulation
toolbox and scripting.

%package devel
Summary:        The GNU Image Manipulation Program
Group:          Development/Libraries/Other
Requires:       libgimp-2_0-0 = %{version}
Requires:       libgimpui-2_0-0 = %{version}
Provides:       gimp-2.0-devel = %{version}
Provides:       gimp-doc = 2.6.4
Obsoletes:      gimp-doc < 2.6.4
Obsoletes:      gimp-unstable-devel < 2.6.0

%description devel
The GIMP is an image composition and editing program. GIMP offers
many tools and filters, and provides a large image manipulation
toolbox and scripting.

This subpackage contains libraries and header files for developing
applications that want to make use of the GIMP libraries.

%lang_package

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

translation-update-upstream
translation-update-upstream po-libgimp gimp20-libgimp
translation-update-upstream po-python gimp20-python
translation-update-upstream po-script-fu gimp20-script-fu
translation-update-upstream po-plug-ins gimp20-std-plug-ins
translation-update-upstream po-tips gimp20-tips
# Safety check for ABI version change.
vabi=`printf "%d" $(sed -n '/#define GIMP_MODULE_ABI_VERSION/{s/.* //;p}' libgimpmodule/gimpmodule.h)`
if test "x${vabi}" != "x%{abiver}"; then
   : Error: Upstream ABI version is now ${vabi}, expecting %{abiver}.
   : Update the apiver macro and rebuild.
   exit 1
fi
# Safety check for API version change.
vapi=`sed -n '/#define GIMP_API_VERSION/{s/.* //;p}' libgimpbase/gimpversion.h | sed -e 's@"@@g'`
if test "x${vapi}" != "x%{apiver}"; then
   : Error: Upstream API version is now ${vapi}, expecting %{apiver}.
   : Update the apiver macro and rebuild.
   exit 1
fi

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
autoreconf -fiv
%configure \
	--disable-static\
%if 0%{?suse_version} >= 1330
	--without-webkit\
	--with-lcms=lcms2\
%endif
	--libexecdir=%{_prefix}/lib\
	--enable-default-binary\
	--enable-mp

make %{?_smp_mflags}

%install
%make_install
install -D -m 0644 %{SOURCE2} %{buildroot}%{_datadir}/gimp/2.0/palettes
%suse_update_desktop_file -N GIMP gimp
rm %{buildroot}%{_libdir}/gimp/2.0/*/*.*a
%find_lang gimp20 %{?no_lang_C}
%find_lang gimp20-libgimp %{?no_lang_C} gimp20.lang
%find_lang gimp20-python %{?no_lang_C} gimp20.lang
%find_lang gimp20-script-fu %{?no_lang_C} gimp20.lang
%find_lang gimp20-std-plug-ins %{?no_lang_C} gimp20.lang
%find_lang gimp20-tips %{?no_lang_C} gimp20.lang
echo "%%defattr(-,root,root)" >plugins.list
echo "%%defattr(-,root,root)" >plugins-python.list
for PLUGIN in %{buildroot}%{_libdir}/gimp/2.0/plug-ins/* ; do
    if grep -q '^#!.*python' $PLUGIN ; then
	echo "${PLUGIN#%{buildroot}}" >>plugins-python.list
    else
	echo "${PLUGIN#%{buildroot}}" >>plugins.list
    fi
done
find %{buildroot} -type f -name "*.la" -delete -print
# Install the macros file:
install -d %{buildroot}%{_sysconfdir}/rpm
sed -e "s/@GIMP_APIVER@/%{apiver}/;s/@GIMP_ABIVER@/%{abiver}/" \
    < $RPM_SOURCE_DIR/macros.gimp > macros.gimp
install -m 644 -c macros.gimp \
           %{buildroot}%{_sysconfdir}/rpm/macros.gimp
%fdupes %{buildroot}%{_datadir}/gtk-doc/
%fdupes %{buildroot}%{_libdir}/gimp/2.0/python/
%fdupes %{buildroot}%{_datadir}/gimp/2.0/

%if 0%{?suse_version} > 1130
%post
%desktop_database_post
%icon_theme_cache_post
%endif

%if 0%{?suse_version} > 1130
%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%post -n libgimp-2_0-0 -p /sbin/ldconfig
%postun -n libgimp-2_0-0 -p /sbin/ldconfig

%post -n libgimpui-2_0-0 -p /sbin/ldconfig
%postun -n libgimpui-2_0-0 -p /sbin/ldconfig

%files -f plugins.list
%doc AUTHORS ChangeLog NEWS* README
%license COPYING LICENSE
%{_bindir}/gimp
%{_bindir}/gimp-2.?
%{_bindir}/gimp-console
%{_bindir}/gimp-console-2.?
%dir %{_datadir}/appdata
%{_datadir}/appdata/gimp.appdata.xml
%{_datadir}/applications/gimp.desktop
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/gimp/
%{_datadir}/gimp/2.0/images/gimp-splash.png
%{_libdir}/gimp/2.0/environ/default.env
%{_libdir}/gimp/2.0/interpreters/default.interp
# Explicitly list modules so we don't lose one by accident
%{_libdir}/gimp/2.0/modules/libcolor-selector-cmyk.so
%{_libdir}/gimp/2.0/modules/libcolor-selector-water.so
%{_libdir}/gimp/2.0/modules/libcolor-selector-wheel.so
%{_libdir}/gimp/2.0/modules/libcontroller-linux-input.so
%{_libdir}/gimp/2.0/modules/libcontroller-midi.so
%{_libdir}/gimp/2.0/modules/libdisplay-filter-color-blind.so
%{_libdir}/gimp/2.0/modules/libdisplay-filter-gamma.so
%{_libdir}/gimp/2.0/modules/libdisplay-filter-high-contrast.so
%{_libdir}/gimp/2.0/modules/libdisplay-filter-lcms.so
%{_libdir}/gimp/2.0/modules/libdisplay-filter-proof.so
%doc %{_mandir}/man?/gimp.*
%doc %{_mandir}/man?/gimp-2.?.*
%doc %{_mandir}/man?/gimp-console.*
%doc %{_mandir}/man?/gimp-console-2.?.*
%doc %{_mandir}/man?/gimprc.*
%doc %{_mandir}/man?/gimprc-2.?.*
%dir %{_sysconfdir}/gimp
%dir %{_sysconfdir}/gimp/2.0
%config %{_sysconfdir}/gimp/2.0/*rc
# split file-aa into own package (bnc#851509
%exclude %{_libdir}/gimp/2.0/plug-ins/file-aa

%files plugin-aa
%{_libdir}/gimp/2.0/plug-ins/file-aa

%files -n libgimp-2_0-0
%dir %{_datadir}/gimp
%dir %{_datadir}/gimp/2.0
%dir %{_libdir}/gimp
%dir %{_libdir}/gimp/2.0
%dir %{_libdir}/gimp/2.0/environ
%dir %{_libdir}/gimp/2.0/interpreters
%dir %{_libdir}/gimp/2.0/modules
%dir %{_libdir}/gimp/2.0/plug-ins
%{_libdir}/libgimp-2.0.so.*
%{_libdir}/libgimpbase-2.0.so.*
%{_libdir}/libgimpcolor-2.0.so.*
%{_libdir}/libgimpconfig-2.0.so.*
%{_libdir}/libgimpmath-2.0.so.*
%{_libdir}/libgimpmodule-2.0.so.*

%files -n libgimpui-2_0-0
%{_libdir}/libgimpthumb-2.0.so.*
%{_libdir}/libgimpui-2.0.so.*
%{_libdir}/libgimpwidgets-2.0.so.*

%files plugins-python -f plugins-python.list
%{_libdir}/gimp/2.0/environ/pygimp.env
%{_libdir}/gimp/2.0/interpreters/pygimp.interp
%{_libdir}/gimp/2.0/python/
# FIXME: Maybe split gimp-lang and gimp-plugins-python-lang

%files lang -f gimp20.lang

%files devel
%doc README.i18n
%{_bindir}/gimptool-2.0
%doc %{_mandir}/man?/gimptool-2.0.*
%{_includedir}/gimp-2.0/
%{_libdir}/*.so
%{_datadir}/aclocal/gimp-2.0.m4
%{_libdir}/pkgconfig/gimp-2.0.pc
%{_libdir}/pkgconfig/gimpthumb-2.0.pc
%{_libdir}/pkgconfig/gimpui-2.0.pc
# Own these repositories to not depend on gtk-doc while building:
%dir %{_datadir}/gtk-doc
%{_datadir}/gtk-doc/html/
%config %{_sysconfdir}/rpm/macros.gimp

%changelog
* Wed Dec 16 2020 Cliff Zhao <qzhao@suse.com>
- Add gimp-CVE-2017-17787.patch: We have to check that strings
  being read at fixed length are properly nul-terminated
  (bnc#1073628 CVE-2017-17787).
* Wed Dec  9 2020 Michael Gorse <mgorse@suse.com>
- Add gimp-fix-issue-3630-postscript-plugin-crashes.patch:
  gsapi_new_instance() now expects a pointer to a NULL-initialized
  pointer. Initialize "void *instance" with NULL. Found by massimo
  (bsc#1178726, glgo#GNOME/GIMP#3630).
* Wed Aug 26 2020 Jia Zhaocong <zcjia@suse.com>
- Add gimp-bsc1073627-CVE-2017-17789.patch:
  Fix heap buffer overflow in PSP importer.
  Check if declared block length is valid before going further.
  (bsc#1073627, bgo#790849, CVE-2017-17789).
* Thu Mar  8 2018 bjorn.lie@gmail.com
- Add gimp-gegl03-buildfix.patch: Port to gegl-03, patch taken from
  debian.
- Following the above port, replace pkgconfig(gegl-0.2) with
  pkgconfig(gegl-0.3) BuildRequires and add libtool BuildRequires:
  and pass autoreconf as the above patch touches the buildsystem.
* Sun Jan  7 2018 zaitor@opensuse.org
- Run spec-cleaner, modernize spec, drop Obsoletes for versions
  no longer supported.
* Sat Jan  6 2018 plinnell@opensuse.org
- Don't build with webkit1, as it is no longer maintained and has
  plenty of security bugs.  This disables the GIMP's built-in help
  browser; it will use an external browser when configured this way.
  This works around a number of security vulnerabilities in Webkit1:
  https://bugzilla.suse.com/show_bug.cgi?id=923223
  https://bugzilla.suse.com/show_bug.cgi?id=906375
  https://bugzilla.suse.com/show_bug.cgi?id=906374
  https://bugzilla.suse.com/show_bug.cgi?id=906373
  https://bugzilla.suse.com/show_bug.cgi?id=1034856
  https://bugzilla.suse.com/show_bug.cgi?id=871792
  https://bugzilla.suse.com/show_bug.cgi?id=879607
  https://bugzilla.suse.com/show_bug.cgi?id=892084
* Wed May 31 2017 plinnell@opensuse.org
- drop mypaint until it is in Factory.
* Fri May 12 2017 plinnell@opensuse.org
- update to 2.8.22
- drop upstream patches - now in the the source
- drop gimp-fix-PDF-Import-filter-crash.patch
- drop gimp-bgo773233-CVE-2007-3126.patch
- conditionalize mypaint support
- full change log:
  https://git.gnome.org/browse/gimp/plain/NEWS?h=GIMP_2_8_22
* Sat Feb 25 2017 mailaender@opensuse.org
- Build with libmypaint support.
* Tue Feb 21 2017 zaitor@opensuse.org
- Add gimp-bgo773233-CVE-2007-3126.patch: Gimp 2.3.14 allows
  context-dependent attackers to cause a denial of service (crash)
  via an ICO file with an InfoHeader containing a Height of zero
  (bgo#773233, CVE-2007-3126).
- Add gimp-fix-PDF-Import-filter-crash.patch: Fix a crash in PDF
  Import filter when importing large image PDF or specifying high
  resolution (bgo#593576).
* Thu Feb  9 2017 zaitor@opensuse.org
- Add conditional gimp-help-browser Obsoletes for Tumbleweed and
  Leap newer than 42.x.
* Wed Feb  8 2017 jengelh@inai.de
- Remove --with-pic, this is only for static libs.
- Trim description on non-main subpackages.
* Fri Feb  3 2017 plinnell@opensuse.org
- update to 2.8.20
- Core:
  - Avoid D-Bus error message when built without D-Bus support
  - fix OS X min required conditional in gimpimagewindow.c
  - Saving to existing .xcf.bz and .xcf.gz files didn't truncate them
  and could lead to unnecessarily large files
  - Text layer created by gimp-text-fontname doesn't respect border
  when resized
  - avoid seeking when saving XCF files to prevent corruption with
  file network shares (fixed since 2014, but not mentioned in NEWS yet)
  GUI:
  - Flow on Paint Dynamics editor dialog: the 'y' axis is indicating
  'Rate' instead 'Flow'
  - Vertical ruler shows artifacts if the status bar isn't showing
  - Tablet stylus misbehaves when crossing the edge of a dock in
  multi-window-mode
  - Disable the new "automatic window tabbing" feature introduced on macOS
  Sierra
  - Improve the visiblity of slider handles with dark themes
  - Make it harder to switch to renaming if selecting already selected
  items in resource lists
  Tools:
  - make toggling to color picker mode of paint tools more robust
  Libgimp:
  - call gimp_file_entry_set_filename() with filename encoding
  Plug-ins:
  - Prevent the Python console from closing by the Escape key
  - Help browser does not launch on OS X
  - Filter 'Edge Detect/Difference of Gaussians' returns empty image
  - only use -xobjective-c for compile commands
  - mkgen.pl: fix calls to write_file() routine to write to current
  directory
  - When printing, the images are composed onto a white background to
  prevent printing a black box instead of a transaprent image
  - Fix color visison deficiency display filters to apply gamma
  correction directly
  Updated Translations:
  - Catalan  - Czech  - Danish  - Finnish  - French  - German
  - Greek  - Hungarian  - Icelandic  - Italian  - Polish
  - Portuguese  - Slovak  - Slovenian  - Scottish Gaelic
  - Spanish  - Swedish
  General:
  - Bug fixes
* Sun Jan 15 2017 zaitor@opensuse.org
- Replace -devel BuildRequires for their pkgconfig version aligned
  with what configure looks for:
  - babl-devel for pkgconfig(babl).
  - gegl-devel for pkgconfig(gegl-0.2).
  - libpng-devel for pkgconfig(libpng).
  - libpoppler-glib-devel for pkgconfig(poppler-glib).
  - xorg-x11-libXfixes-devel for pkgconfig(xfixes).
  - xorg-x11-libXpm-devel for pkgconfig(xpm).
  - zlib-devel for pkgconfig(zlib).
- Add an explicit pkgconfig(cairo-pdf) BuildRequires: configure
  checks for it (full pdf support).
- Run spec-cleaner: drop obsolete clean, modernise macros.
- No longer depend on libwebkit-devel for Tumbleweed and pass
  - -disable-webkit to configure for Tumbleweed.
* Sun Jul 31 2016 plinnell@opensuse.org
- update to 2.8.18
- Drop gimp-Multiple-Use-After-Free.patch - upstreamed
  +Core: - Initialize fontconfig cache in separate thread to keep GUI
  responsive on first startup
  - Properly recognize layer masks as deactivated, e.g. for moving layers
  - Create $XDG_DATA_HOME if it doesn't exist
  - (CVE-2016-4994) Multiple Use-After-Free when parsing XCF channel
  and layer properties
  - Fix progress access to prevent crash on rapid sequence of commands
  - Fix crash in gimp-gradient-segment-range-move
  +GUI:
  - Disable color picker buttons on OS X to prevent a GUI lockup
  - Disable "new-style" full-screen mode on OS X to prevent a crash
  - Pulsing progress bar in splash screen to indicate unknown durations
  - Fix gamut warning color for lcms display filter
  - Fix unbolding of bold font on edit
  - Prevent accidental renaming of wrong adjacent item
  +Installer:
  - Change compression settings to decrease size by 20%%
  - Add Catalan, Danish, French, Dutch
  +Plug-ins:
  - Fix crash on sRGB JPEG image drag & drop
  - Fix ambiguous octal-escaped output of c-source
  - Fix KISS CEL export
  - Fix progress bar for file-compressor
  - Make Script-Fu regex match return proper character indexes for
  Unicode characters
  - Fix Script-Fu modulo for large numbers
  +General:
  - Documentation updates
  - Bug fixes
  - Translation updates
* Thu Jun 23 2016 zaitor@opensuse.org
- Fix CVE-2016-4994 (boo#986021, bgo#767873):
  + Add gimp-Multiple-Use-After-Free.patch: Multiple Use-After-Free
    when parsing XCF channel and layer properties.
* Sat Dec  5 2015 plinnell@opensuse.org
- Explcitly declare the libgimp version in Requires, so upgrades
  bring in the updated libraries as well. Makes the upgrade from
  2.8.x > 2.8.16 seamless and avoids an error on start.
* Sat Nov 28 2015 plinnell@opensuse.org
- update to version 2.8.16
- fix a couple of rpmlint warnings
  +Core:
  - Seek much less when writing XCF
  - Don't seek past the end of the file when writing XCF
  - Windows: call SetDLLDirectory() for less DLL hell
  - Fix velocity parameter on .GIH brushes
  - Fix brokenness while transforming certain sets of linked layers
  +GUI:
  - Always show image tabs in single window mode
  - Fix switching of dock tabs by DND hovering
  - Don't make the scroll area for tags too small
  - Fixed a crash in the save dialog
  - Fix issue where ruler updates made things very slow on Windows
  +Plug-ins:
  - Fix several issues in the BMP plug-in
  - Make Gfig work with the new brush size behavior again
  - Fix font export in the PDF plug-in
  - Support layer groups in OpenRaster files
  - Fix loading of PSD files with layer groups
  + General:
  - OSX build system fixes
  - Bug fixes
  - Translation updates
* Wed Apr  8 2015 dimstar@opensuse.org
- Replace liblcms-devel BuildRequires with pkgconfig(lcms2): gimp
  has been ported to lcms2 since version 2.8.8.
* Sat Sep 20 2014 mailaender@opensuse.org
- update to version 2.8.14:
  + Fix libtool versioning (forgot to bump gimp_interface_age).
- Changes from Version 2.8.12:
  + Core:
  - Fix brush sizes when used from plug-ins.
  - Make XCF loading more robust against broken files.
  + GUI:
  - Make sure the widget direction matches the GUI language.
  - Remove the option to disable the warning when closing a
    modified image.
  - Fix canvas overlay widgets (like the text options) for
    tablets.
  - Make DND work between images in one dockable.
  + Libgimp: Make gimp_image_get_name() return the string used for
    the image title.
  + Plug-ins:
  - Make script-fu-server more secure by listening to 127.0.0.1
    by default and add a warning about changing that IP. This
    breaks the procedure's API, but for security reasons.
  - Bring back proper script-fu translations.
  + General:
  - Add Jenkins tutorial.
  - Documentation updates.
  - Bug fixes.
  + Updated translations.
- Drop gimp-use-recommended-freetype-include.patch: fixed upstream.
* Wed Dec 11 2013 hrvoje.senjan@gmail.com
- Add gimp-use-recommended-freetype-include.patch:
  Freetype upstream recommends using their macros together with
  ft2build include. Positive sideeffect is that this patch makes
  it build with both freetype2 2.5.1, and older versions.
* Sun Dec  1 2013 dimstar@opensuse.org
- Update to version 2.8.10:
  + Core:
  - Set manifest as Windows 8 compatible.
  + GUI:
  - Indicate if a file was exported in the Quit dialog.
  - Add shortcuts and hint labels to the close and quit dialogs
    that make closing and quitting easier and more consistent.
  - Rename the File->Export menu labels to match Save/Save as.
  - Fix keyboard shortcuts on OSX Mavericks.
  - Don't open lots of progress popups when opening many files.
  - Correctly restore the hidden state of docks in single window
    mode.
  + Libgimp:
  - Fix exporting an image consisting of a single layer group.
  - Don't attempt to pick transparent colors.
  + Plug-ins: Fix crash in LCMS plugin if RGB profile was missing.
  + General:
  - Fix compile on NetBSD (missing -lexecinfo).
  - Bug fixes.
  + Updated translations.
* Tue Nov 26 2013 dimstar@opensuse.org
- Update to version 2.8.8:
  + General:
  - Fix lots of places to use GIO to get proper file sizes and
    times on windows.
  - Add an AppData file for GIMP.
  - Backport lcms2 support from master, because lcms1 is not
    getting bug fixes any longer.
  - Lots of bug fixes.
  + Core:
  - Make sure indexed images always have a colormap.
  - Fix language selection via preferences on Windows.
  - Don't crash on setting a large text size.
  + GUI:
  - Keep the same image active when switching between MWM and
    SWM.
  - Make sure all dockables are properly resizable (particularly
    shrinkable).
  - Add links to jump directly to Save/Export from the
    Export/Save file extension warning dialogs.
  + Libgimp: Fix GimpPickButton on OSX.
  + Plug-ins:
  - Properly document plug-in-autocrop-layer's PDB interface.
  - Fix importing of indexed BMPs.
  + Updated translations.
- Split out ASCII-Art plugin in subpackage gimp-plugin-aa. The
  package supplements gimp and libaa1, so any user having both
  installed will get the plugin as well (bnc#851509).
* Sat Sep 21 2013 dimstar@opensuse.org
- Change RPM Group of shared library package to System/Libraries.
* Mon Aug 19 2013 dimstar@opensuse.org
- Drop branding-upstream subpackage: starting with openSUSE 13.1,
  we will no longer replace the gimp splashcreen with a branded
  version. This in order to maintain the identity of gimp.
- Remove gimp-branding Requires.
- Obsolete gimp-branding.
* Sat Jun 22 2013 zaitor@opensuse.org
- Update to version 2.8.6:
  + Core:
  - Fix saving to URIs, it was broken to only allow exporting,
    and fix save/export of compressed files.
  - Fix brush spacing for drawing in any direction.
  - Increase the maximum size of clipboard brushes and patterns
    to 1024x1024.
  - Make sure data objects are saved when only their name was
    changed.
  + GUI:
  - Don't allow single-window docks to shrink smaller than their
    requisition.
  - Make sure a single-window's right docks keep their size
    across sessions.
  - Allow to change the spacing of non-generated brushes again.
  - In single-window mode, make Escape move the focus to the
    canvas, and beep if the focus is already there.
  - Be smarter about unavailable fonts, and don't crash.
  - Make clicking the single-window's close button quit GIMP.
  - Make view-close (Ctrl+W) only close image windows and tabs,
    not docks.
  + Libgimp: Add SIGNED_ROUND() which also rounds negative values
    correctly.
  + Plug-ins:
  - Make GIMP_PLUGIN_DEBUG work again after GLib changed logging.
  - Fix zealous crop for transparent borders.
  + Installer: Add Hungarian translation.
  + Data: Add a default "Color from Gradient" dynamics and tool
    preset.
  + General: Lots of bug fixes.
  + Updated translations.
* Thu Mar  7 2013 dimstar@opensuse.org
- Update to version 2.8.4:
  + Core:
  - Move the OSX gimpdir to "~/Library/Application Support".
  + GUI:
  - Better names for the default filters in save and export
  - Make tool drawing (esp. the brush outline) much more
    responsive
  - Remember the "maximized" state across sessions
  - Simplify the splash image code a lot, makes it appear
    immediately again
  - Allow the text tool to start on an image without layers
  - Various fixes for text style attribute handling
  - Set unconfigured input devices to eraser if GTK+ says they
    are erasers
  - Make language selectable in Preferences on OSX
  + Libgimp:
  - Make libgimp drawable combo boxes aware of layer groups
  - Make sure plug-in windows appear on top on OSX
  - Fix item width in GimpPageSelector (used e.g. in PDF import)
  + Plug-ins:
  - Better default values in the Drop Shadow script
  - Fix a whole bunch of bugs in the BMP plug-in
  - On OSX, use the system's screenshot utility
  + Installer:
  - Add Brazilian-Portuguese translation to the Windows installer
  + Source and build system:
  - Many improvements to the OSX bundle build system
  - Support automake 1.13
  + General: Lots of bug fixes
  + Updated translations.
- Drop gimp-CVE-2012-5576.patch: fixed upstream.
* Tue Nov 27 2012 dimstar@opensuse.org
- Add gimp-CVE-2012-5576.patch: fix memory corruption vulnerability
  when reading XWD files (bnc#791372, bgo#687392, CVE-2012-5576).
* Wed Aug 29 2012 dimstar@opensuse.org
- Update to version 2.8.2:
  + Core:
  - Make tag matching always case-insensitive
  - Let the tile-cache-size default to half the physical memory
  + GUI:
  - Mention that the image was exported in the close warning
    dialog
  - Make sure popup windows appear on top on OSX
  - Allow file opening by dropping to the OSX dock
  - Fix the visibility logic of the export/overwrite menu items
  - Remove all "Use GEGL" menu items, they only add bugs and zero
    function
  - Improve performance of display filters, especially color
    management
  - Fix the image window title to comply with the save/export
    spec and use the same image name everywhere, not only in the
    title
  - Fix positioning of pasted/dropped stuff to be more reasonable
  + Libgimp:
  - Move gimpdir and thumbnails to proper locations on OSX
  - Implement relocation on OSX
  - Allow to use $(gimp_installation_dir) in config files
  + Plug-ins:
  - Fix remembering of JPEG load/save defaults
  - Revive the page setup dialog on Windows
  + Source and build system:
  - Add Windows installer infrastructure
  - Add infrastructure to build GIMP.app on OSX
  + General:
  - Lots of bug fixes
  + Updated translations.
- Drop gimp-CVE-2012-3236.patch: fixed upstream.
- Clean spec-file using spec-cleaner.
* Mon Jun 25 2012 vuntz@opensuse.org
- Add gimp-CVE-2012-3236.patch: fix crash in file handling for fit
  files. Fix CVE-2012-3236, bnc#768376.
* Mon May 14 2012 vuntz@opensuse.org
- Correctly version librsvg-devel BuildRequires: 2.36.0 is needed.
  We don't version the BuildRequires on 12.1 and earlier to avoid
  useless unresolvables; it will just result in file-svg plugin not
  being built when librsvg is not recent enough there.
* Thu May  3 2012 badshah400@gmail.com
- Update to version 2.8.0:
  + Core: Add gimp's own GimpOperationBrightnessContrast because
    GEGL one is different
  + Plug-ins: Fix some GFig rendering issues
  + Source and build system: Depend on Babl 0.1.10, GEGL 0.2.0
    and some other new library versions.
* Sat Apr  7 2012 vuntz@opensuse.org
- Update license from GPL-2.0+ to GPL-3.0+, following upstream
  change.
- Completely drop HAL-related packaging since it is now gone
  upstream:
  + Remove build_hal macro
  + Remove optional hal-devel BuildRequires.
  + Remove optional gimp-module-hal subpackage.
  + Note that we already have a Obsoletes for gimp-module-hal.
- Add pkgconfig(gudev-1.0) BuildRequires for the new gudev input
  module.
- Add ghostscript-devel, ghostscript-library, libbz2-devel,
  libjasper-devel, pkgconfig(atk), pkgconfig(xcursor)
  BuildRequires: new dependencies upstream.
  + Note about ghostscript-library: ideally, we'd avoid listing it
    explicitly, but in OBS, ghostscript-mini is preferred by
    default, but it is not enough for gimp.
- Add explicit pkgconfig(gdk-pixbuf-2.0) BuildRequires so it can be
  versioned.
- Add explicit libjpeg-devel, xorg-x11-libXpm-devel, zlib-devel
  BuildRequires: they were missing before.
- Add libxslt-tools BuildRequires (or libxslt-devel on versions of
  openSUSE <= 12.1) to have xsltproc installed.
- Add fdupes BuildRequires and use %%fdupes in %%install to avoid
  duplicated files.
- Change gimp-doc Obsoletes in devel subpackage from <= to < to
  avoid rpmlint warning about self-obsoletion.
* Fri Apr  6 2012 dimstar@opensuse.org
- Update to 2.8.0-RC1:
  + User Interface:
  - Single-Window Mode
  - Multi-Column Dock Windows
  - More Screen Real Estate For Dockable Dialogs
  - Save And Export
  - Layer Groups
  - Tools Drawn With Cairo
  - On-Canvas Text Editing
  - Keyboard Shortcut Changes
  - Simple Math In Size Entries
  + Tools & Plug-ins:
  - Brush System Improvements
  - Tool Preset Improvements
  - Cage Transform Tool
  - File Plug-Ins
  - For Tablet Users
  - Resource Tagging
  + Miscellaneous:
  - Enhancements to scripting abilities
  - API changes
  + For detailed changes, see NEWS file and
    http://www.gimp.org/release-notes/gimp-2.7.html
* Wed Feb  1 2012 vuntz@opensuse.org
- Update to version 2.6.12:
  + Bugs fixed: bgo#623045, bgo#627328, bgo#631728, bgo#631885,
    bgo#639203, bgo#640219, bgo#640612, bgo#641259, bgo#646947,
    bgo#652280, bgo#660305.
  + Updated translations.
- Drop gimp-CVE-2010-4540-and-more.patch: fixed upstream.
- Drop gimp-CVE-2010-4543.patch: fixed upstream.
- Drop gimp-fix-linking.patch: fixed upstream.
- Drop gimp-CVE-2011-2896.patch: fixed upstream.
- Drop gimp-pyslice-cellspacing-fix.patch: fixed upstream.
- Drop gimp-poppler-0.18.patch: fixed upstream.
- Remove call to autoreconf and libtool BuildRequires: they were
  only needed for gimp-fix-linking.patch.
* Fri Oct 21 2011 vuntz@opensuse.org
- Change gimp-2.0-scanner-plugin Recommends to a Suggests: this
  installs xsane by default, and really, xsane is so horribly
  broken UI-wise that we don't want that.
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Wed Oct 12 2011 vuntz@opensuse.org
- Add a warning comment about changing the content of the branding
  package, to make our life easier in branding-openSUSE.
* Thu Oct  6 2011 vuntz@opensuse.org
- Add iso-codes Recommends since the iso-codes data is used at
  runtime, but its presence is not mandatory.
- Remove explicit gtk2 Requires: the library will get
  automatically added to the list of Requires.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update gimp-fix-linking.patch: add another missing -lm.
- Add gimp-poppler-0.18.patch: fix build with poppler 0.17/0.18.
* Fri Sep  9 2011 vuntz@opensuse.org
- Add gimp-fix-linking.patch: fix linking issue.
- Add gimp-CVE-2011-2896.patch: Fix heap corruption and buffer
  overflow in LZW code. Fix bnc#711491, CVE-2011-2896.
- Add gimp-pyslice-cellspacing-fix.patch: fix a crash in the
  pyslice plugin.
- Add call to autoreconf, needed by gimp-fix-linking.patch.
* Wed Jul  6 2011 vuntz@opensuse.org
- Change branding-upstream subpackage:
  + Add Requires for gimp since the branding package is useless
    without it.
  + Update summary and description.
  + Make noarch.
- Change branding Requires in main subpackage to be "= %%{version}",
  instead of ">= 2.4", which is wrong.
* Wed Jun 15 2011 vuntz@opensuse.org
- Fix build on Factory, by not excluding the
  libcontroller-linux-input.so module from the file list of the
  main package when we build without hal. It was only excluded to
  be part of a hal subpackage when there is the hal dependency.
* Sat Jun 11 2011 vuntz@opensuse.org
- On 12.1 and later, stop building the gimp-module-hal subpackage:
  + we don't want hal anymore on 12.1 and later (see bnc#697016).
    We use a build_hal define to control that behavior.
  + remove hal-devel BuildRequires
  + do not build a gimp-module-hal subpackage anymore
  + add gimp-module-hal Obsoletes for smooth upgrades
* Tue Feb 15 2011 vuntz@opensuse.org
- Add gimp-CVE-2010-4540-and-more.patch and
  gimp-CVE-2010-4543.patch to fix buffer overflows: CVE-2010-4540,
  CVE-2010-4541, CVE-2010-4542, CVE-2010-4543. Fix bnc#662043.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
* Fri Jan  7 2011 vuntz@opensuse.org
- Move ownership from various directories from gimp to
  libgimp-2_0-0, to not force external gimp plug-ins/modules/etc.
  to have a gimp BuildRequires for directory ownership.
* Mon Dec 20 2010 vuntz@opensuse.org
- Split gimp libraries in libgimp-2_0-0 and libgimpui-2_0-0
  subpackages, and add baselibs.conf for those. Fix bnc#660439.
- Change accordingly the Requires of the devel package, and the
  scriptlets to run ldconfig.
- Remove explicit glib2-devel and gtk2-devel Requires in devel
  package: they will automatically be added the pkgconfig() way.
- Move the gimptool-2.0 man page to the devel subpackage, where the
  binary lives.
* Tue Nov 23 2010 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Mon Oct  4 2010 vuntz@opensuse.org
- Update to version 2.6.11:
  + bgo#631199: Printing and Print preview broken with cairo 1.10
  + Other bugs fixed: bgo#572865, bgo#628893, bgo#623850,
    bgo#624487, bgo#557380, bgo#627009, bgo#626020, bgo#624698,
    bgo#624275.
  + Updated translations.
* Mon Aug  9 2010 vuntz@opensuse.org
- Add alsa-devel BuildRequires to build the MIDI Input module.
* Tue Aug  3 2010 dimstar@opensuse.org
- Update to version 2.6.10:
  + bgo#613328: TGA files saved with incorrect header yOrigin data
  + bgo#623290: Save As... does not save Windows Bitmap as default
    in dialog
  + bgo#621363: CMYK decompose broken
  + bgo#595170: brush - color from gradient works wrong in
    greyscale
  + bgo#613838: Error in gimp-hue-saturation PDB call
  + bgo#622608: GIMP crashes when clicking any scroll bar from
    combo boxes
  + bgo#565459: newly opened images are put into the background
- Changes from version 2.6.9:
  + bgo#612618: Font selection remains visible
  + bgo#620604: Description of "histogram" procedure is slightly
    inaccurate
  + bgo#541586: Tool options not saved/loaded correctly?
  + bgo#614153: Importing PDF files with long titles
  + bgo#599233: Dialog of "Save as BMP" ignores changes which are
    not made with a mouse
  + bgo#610478: Layer preview suddenly stops getting updated
  + bgo#609026: leaks shared memory
  + bgo#609056: Exporting to Alias PIX format fails
    are always in English
  + bgo#607242: GIMP 2.7.0 fails to build against libpng 1.4.0
  + bgo#606372: Saving to .ppm fails on indexed colorspace
  + bgo#604508: gimp-layer-new-from-visible should work from
    updated projection
  + Fix crashes: bgo#600112, bgo#565001, bgo#604820, bgo#603711
  + Other fixes: bgo#622234, bgo#622196, bgo#608188, bgo#605237
  + Updated translations.
- Drop gimp-new-libpng.patch and gimp-fix-statusbar.patch, both
  came from upstream git and are now included.
* Mon Jun 14 2010 vuntz@opensuse.org
- Ship the openSUSE palette so that it's available in GIMP.
* Sun May 23 2010 vuntz@opensuse.org
- Add gimp-fix-statusbar.patch to fix missing widgets in status
  bar. Fix bnc#601712.
* Sun May 23 2010 vuntz@opensuse.org
- Move the input device module to a specific package, to isolate
  the HAL dependency. Fix bnc#601947.
* Tue Apr  6 2010 vuntz@opensuse.org
- Add gimp-new-libpng.patch to fix build with newer libpng.
* Fri Dec 11 2009 vuntz@opensuse.org
- Update to version 2.6.8:
  + bgo#470698 - MapObject cannot modify highlight
  + bgo#593848 - FG color changed to black when FG-BG Editor tab
    created
  + bgo#594651 - layer.scale() raises RuntimeError
  + bgo#594998 - Keyboard shortcuts does not work for first image
    when dock is focused
  + bgo#599765 - F1 key on gimp-tool-align in menu have wrong link
    and it open gimp-tool-move
  + bgo#600484 - Gimp BMP Integer Overflow Vulnerability
  + bgo#600741 - "read_channel_data()" Integer Overflow
    Vulnerability
  + bgo#601891 - gimp_image_get_selection returns None
  + bgo#602761 - plug-in-grid: Parameters Horizontal/Vertical
    Spacing and Horizontal/Vertical Offset are
    reversed.
  + bgo#603995 - PCX plugin doesn't sanitize input to avoid
    allocation overflows.
  + bgo#603998 - PCX: Calculating amount of memory to allocate may
    overflow.
  + bgo#604000 - SGI: sanitize input
  + bgo#604001 - SGI: Calculating amount of memory to allocate may
    overflow.
  + bgo#604002 - SGI: RLE encoded input data may write beyond
    allocated buffers
  + bgo#604004 - SGI: allocate memory consistently
  + bgo#604008 - GBR, PAT: sanitize input data
  + bgo#604078 - Crash when pressing Backspace with Free Select
    Tool
  + Updated translations.
* Mon Oct 26 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Fri Sep  4 2009 vuntz@novell.com
- Change Name in .desktop file to "GIMP", not "The GIMP". The
  project has stopped calling it the GIMP.
* Thu Aug 20 2009 crrodriguez@suse.de
- add support for versioning external plugins, providing
  rpm macros gimp_abi_version and gimp_api_version
* Wed Aug 19 2009 beineri@opensuse.org
- Everyone calls it "GIMP" so let us follow that in the application
  start menu, fixes problem with launcher finding it (bnc#508279).
* Fri Aug 14 2009 beineri@opensuse.org
- Update to version 2.6.7:
  + bgo#591017 - Tablet pan is not working as fast as it should
  + bgo#577581 - Crashes when using any colors tool/function on
    Windows
  + bgo#589667 - GIMP crashes when clicking GEGL Operation on
    Windows
  + bgo#569833 - file-jpeg-save erroneous with small quality
    values
  + bgo#590638 - Changing palettes from list to grid view loses
    "locked to dock" status
  + bgo#589674 - "Send by Email" does not update "Filename"
  + bgo#589674 - "Send by Email" does not update "Filename"
  + bgo#586851 - Transparent BMP files fail to load
  + bgo#589205 - help-browser uses deprecated (and sometimes
    broken) webkit call
  + bgo#582821 - 'Sphere Designer' does not reset correctly...
  + bgo#570353 - first time open of .svg file ignores the
    requested units
  + bgo#555777 - Export to MNG animation fails
  + bgo#577301 - Dithering with transparency is broken for
    "positioned" method
  + bgo#493778 - metadata plug-in crashes on some images
  + bgo#567466 - PNG comment not found if more than 1 tEXt chunks
  + bgo#585665 - Exporting to PSD with a blank text layer creates
    a corrupt file
  + bgo#586316 - Levels tool does not adjust output levels
    correctly if input levels are changed
  + bgo#569661 - Import from PDF throws errors when entering
    resolution in pixels per millimetre
  + bgo#567262 - Black pixels appear in "Spread" filter preview
  + bgo#554658 - Path Dialog: Path preview pics not to see
    constantly
  + bgo#167604 - gimp_gradient_get_color_at() may return
    out-of-bounds values
  + bgo#567393 - Rectangle select tool size shrinks to 0 if size
    is larger than the image and the up or down arrow
    is pressed
  + bgo#587543 - crash when invoking certain actions by keyboard
    shortcut
  + bgo#563029 - Closing maximized image doesn't restore document
    window size
  + bgo#585488 - Perspective transformation on a layer with a mask
    causes crash
  + bgo#586008 - GIMP crashes when right-click canceling a drawing
    action initiated outside layer boundaries
  + bgo#584345 - when printing, the number of copies should be
    reset to 1
  + bgo#557061 - Alpha to Logo
  + bgo#472644 - Rotate with clipping crops the whole layer
  + bgo#577575 - transform tool fills underlying extracted area
    wrongly
  + bgo#555738 - Image display is wrong after undoing canvas size
  + bgo#577024 - help-browser plugin crashes when used with webkit
    1.1.3
  + bgo#555025 - Action GEGL box widgets weirdness
- Drop gimp-gegl-babl-versions-check.patch: fixed upstream.
* Thu Jul 30 2009 vuntz@novell.com
- Add a Supplements between gimp and gimp-help to get the
  help-browser package automatically installed.
- Update descriptions of packages.
* Fri Jul 24 2009 beineri@opensuse.org
- Split off gnome-help-browser sub-package to save 4MB libwebkit
  dependency on Live-CDs where gimp-help is not included.
- Only include latest ChangeLog.
* Thu Jun 11 2009 vuntz@novell.com
- Add gimp-gegl-babl-versions-check.patch to fix the code used to
  check the babl and gegl version. Taken from Fedora/upstream.
* Tue Mar 17 2009 mboman@suse.de
- Update to version 2.6.6:
  + bgo#571117 - lcms plug-in crashes on broken profile
  + bgo#575154 - changing the help browser preference may not work
  + bgo#573542 - blur plugin: bug in the first line
  + bgo#572403 - gimp-2.6 crashed with SIGSEGV in
    IA__g_object_get()
  + bgo#573695 - 1-bit white background saved as PBM becomes all
    black
  + bgo#573488 - Small bug in Filter>Distorts>Ripple
  + bgo#572156 - top left pixel position/coordinate is not 0,0 but
    1,1
  + bgo#472644 - Rotate with clipping crops the whole layer
  + Translation updates
- Remove glibc-devel from Requires in -devel package
- Use py_requires.
- Remove gimp-enable-gtk-deprecated.patch: unneeded now.
* Tue Feb 17 2009 vuntz@novell.com
- Remove some BuildRequires:
  + libcurl-devel: not needed since we have gio
  + gnome-keyring-devel, gnome-vfs2-devel, libgnomeui-devel: not
    needed either since we have gio
- Fix Provides/Obsoletes for gimp-doc in devel package.
* Mon Feb 16 2009 mboman@suse.de
- Update to version 2.6.5:
  + bgo#571628 - Scaling image to 25%% turn background from white
    to grey
  + bgo#567840 - GIMP's GtkScaleButton conflicts with GTK's
  + bgo#569043 - GEGL tool - missing Operation Settings for all
    sub-tools
  + bgo#568890 - don't rely on GtkAction implementation details
  + bgo#568909 - wrong RGB values for color names in
    libgimpcolor/gimprgb-parse.c
  + bgo#568839 - wrong hex RGB value for the color names slategrey
    and slategray
  + bgo#559408 - Brushes dragged to the image window look strange
  + bgo#563337 - Rectangle Select Tool does not allow 1:1 fixed
    ratio
  + bgo#568016 - Black pullout parameter of plug-in-newsprint has
    no effect
  + bgo#562818 - First image opened in GIMP offset
  + bgo#562213 - Align Tool doesn't work properly if it is the
    active tool at startup
  + Translation updates
- Add gimp-enable-gtk-deprecated.patch due to using deprecated
  API call gtk_widget_get_action. Upstream is working on it so
  could probably be removed with the next version update
- Merge gtk-doc from -doc to -devel
- Fix BuildRequires according to what's in configure.ac:
  * Add: babl-devel, cairo-devel, fontconfig-devel, glib2-devel,
    gnome-keyring-devel, gnome-vfs2-devel, gtk2-devel,
    libcurl-devel, libpng-devel, pango-devel,
    xorg-x11-libXfixes-devel
  * Remove: BuildRequires: alsa-devel, cups, cups-devel,
    curl-devel, gnome-common, gnutls-devel, gtk-doc,
    libgimpprint, libgimpprint-devel, libglade2-devel,
    libgnomeprintui-devel, libgtkhtml-devel,
    libwnck-devel, perl-XML-Parser, postfix,
    python-devel, slang-devel
* Tue Feb 10 2009 vuntz@novell.com
- Remove non-upstream translations: they'll get out-of-date.
* Mon Jan 19 2009 crrodriguez@suse.de
- remove "la" files [BNC#357465]
* Sat Jan  3 2009 mboman@suse.de
- Update to version 2.6.4:
  + bgo#565223 - Perspective transformation jagged edges / comb effect
  + bgo#563985 - jpg save dialog: "cancel" is treated like "commit"
    for settings
  + bgo#564087 - Using clone tool on a layer with a part out of canvas
    causes crashes
  + bgo#564593 - crash when the drawable is changed while a color tool
    is active
  + bgo#564869 - GIMP crashes on selecting Tools->GEGL operation
  + bgo#565138 - python-fu-foggify does not check if image is in rgb mode
  + bgo#563130 - Hue selection mode does not cross the 0-360 degrees line
  + bgo#563179 - Scrollbars not resized when we extend the canvas size
  + bgo#562459 - PF_PALETTE: 'TypeError' when used in a plugin that is
    registered in <Image>
  + bgo#562427 - Compilation with --as-needed
  + bgo#562386 - PF_SLIDER and PF_SPINNER 'Step' values do not change
    consistently...
  + bgo#562366 - Default image dimensions are not correctly
    transferred in the file/new dialog box
  + bgo#561899 - GIMP can't save to mounted filesystem if file exists
  + Translation updates
* Mon Dec 29 2008 mboman@suse.de
- Update to version 2.6.3:
  + bgo#558454 - Plugin Map Color Range disappears from GIMP
  + bgo#559239 - Error while loading psd-data
  + bgo#560903 - Explicit zooming with e.g. '1' should handle
    zoom-focus better
  + bgo#560245 - Zoom selection always centered in the Navigation tab
  + bgo#559490 - Wrong lang tags for 'no'
  + bgo#559292 - SOTA Chrome cannot accept different textures
  + bgo#560375 - Clearing an already empty document history crashes GIMP
  + bgo#559580 - Image windows need better default locations
  + bgo#560283 - "Scale image..." causes distortion around edges
  + bgo#559716 - Changing crop size in Crop Tool Options can make UI
    unresponsive
  + bgo#558549 - Stroking a single-point path with a paint tool
    crashes GIMP
  + bgo#559015 - Move tool gives bad information about px moved
  + bgo#558660 - help behavior for locales without manual translation
  + Translation updates
- Remove gimp-help-fallback-en.patch. Fixed upstream
* Fri Dec 19 2008 mauro@suse.de
- Added hu-po.tar.bz2 to fix bnc#460663
  + Updated hungarian translation.
* Mon Nov  3 2008 sbrabec@suse.cz
- If help translation does not exist, fallback to English
  (bgo#558660).
* Fri Oct 31 2008 sbrabec@suse.cz
- Updated to version 2.6.2:
  * scaling speed improved
  * several crash, bug and regression against 2.4 fixes
  * translation updates
  * See NEWS for more
* Fri Oct 10 2008 sbrabec@suse.cz
- Updated to version 2.6.1:
  * 10 important crash and bug fixes
  * translation updates
  * See NEWS for more
* Mon Oct  6 2008 sbrabec@suse.cz
- Conflict with other branding providers (FATE#304881, bnc#429324).
* Thu Oct  2 2008 sbrabec@suse.cz
- Updated to version 2.6.0, the new stable branch:
  * depends on GEGL and uses it optionally in some color operations
  * UI refactoring
  * many improvements and new features
  * See NEWS for details.
* Thu Sep  4 2008 sbrabec@suse.cz
- Recommend gimp-2.0-scanner-plugin (bnc#422558).
* Fri Aug 22 2008 sbrabec@suse.cz
- Updated to version 2.4.7:
  * python binding fixes
  * fixed memory leak
  * bug fixes
  * translation updates
  * See NEWS for details.
* Wed Jul 16 2008 sbrabec@suse.cz
- Updated to version 2.4.6:
  * many fixes
  * translation updates
  * See NEWS for details.
* Tue Apr 15 2008 sbrabec@suse.cz
- Fixed dependencies of the branding package.
* Mon Apr 14 2008 sbrabec@suse.cz
- Use packageand form of branding supplement.
* Thu Mar 27 2008 sbrabec@suse.cz
- Added support for vendor branding (bnc#372091).
* Mon Mar  3 2008 sbrabec@suse.cz
- Updated to version 2.4.5:
  * many fixes
  * many corrections
  * translation updates
  * See NEWS for details.
* Wed Jan 30 2008 sbrabec@suse.cz
- Split plugins requiring python-gtk into a separate package
  (bnc#339862).
* Fri Dec  7 2007 sbrabec@suse.cz
- Removed gutenprint from BuildRequires (#245683#c23).
- Require python-gtk (#339862).
* Wed Oct 24 2007 sbrabec@suse.cz
- Updated to version 2.4.0:
  * further improved the rectangle select and crop tools
  * allow to mark out-of-gamut colors when doing a soft proof
  * bug fixes
- Package renamed from gimp-unstable to gimp.
* Thu Oct 11 2007 sbrabec@suse.cz
- poppler devel package names prepended by "lib".
* Mon Oct  8 2007 sbrabec@suse.cz
-  Use binding specific poppler devel package.
* Mon Sep 24 2007 stbinner@suse.de
- update to GIMP 2.3 Release Candidate 3 (#327516)
  * Changes in GIMP 2.4.0-rc3:
  - use the new format for storing recently used files
  - added conversion options to the color profile conversion plug-in
  - allow to disable the toolbox menu on all platforms
  - further improved handling of the JPEG settings
  - switch tabs when hovering over them
  - added a PDB function to remove the alpha channel from a layer
  - plug-in previews remember the state of the Preview checkbox
  - allow to grow the image/layer using the Crop tool
  * Changes in GIMP 2.4.0-rc2:
  - more improvements and bug fixes in the rectangle tools
  - antialias the display for zoom levels between 100%% and 200%%
  - fix zoomed-out display problems
  - improve handling of JPEG settings
  - fix script-fu error reporting
  - on OS X, get rid of menubars in windows and use the global menubar
  - fix plug-ins using GimpZoomPreview
  - throw properly catchable exceptions from foreign script-fu function
    (like PDB wrappers)
  * Changes in GIMP 2.4.0-rc1:
  - further improvement to the Print plug-in
  - completed the color management functionality for 2.4
  - store JPEG setting with the image and use them when saving as JPEG
  - further improved the rectangle tools, in particular handling of the
    fixed aspect ratio
  - added color profile selector widget
  - further improved the display quality for zoomed-out views
* Tue Sep 11 2007 stbinner@suse.de
- add Conflict with gimp-lang (#307289)
* Mon Jul 30 2007 maw@suse.de
- Update to version 2.3.19:
  + support long layer names in PSD files
  + improved EXIF handling in the JPEG file plug-in
  + added control for the playback speed in the Animation Playback plug-in
  + avoid needless image preview invalidation
  + allow to edit the image comment in the Image Properties dialog
  + further improved rectangle tools
  + made JPEG save parameters user-configurable
  + avoid color conversions between identical ICC color profiles
  + improved Print plug-in
  + improved loading and saving of indexed TGA images
  + temporarily show the hidden image statusbar while the progress is active
  + added support for loading .abr v6 Photoshop brushes
  + improved usability of color scales
  + improved display quality of zoomed-out image view
  + improved import of multi-page TIFF files
  + reduced rounding errors in Blur routines (core and plug-ins)
  + further improved parameter checks in the PDB
  + added support for loading .abr v2 Photoshop brushes
  + improved border behavior of the Blur tool
  + show the brush outline at the Clone tool's source position
  + added libgimpbase API to retrieve the user's Pictures folder
  + add a shortcut to the user's Pictures folder to the file-chooser dialog
  + improved the quality of the Motion Blur filter
  + save paths in TIFF files
  + let the Screenshot plug-in name the new layer after the window
  + use memory slices to reduce memory fragmentation
  + some code cleanup
  + lots of bug fixes
- Remove upstreamed gimp-psd-overflow.patch and gimp-sunras-overflow.patch.
* Wed Jul 18 2007 maw@suse.de
- Respin gimp-psd-overflow.patch (http://bugzilla.gnome.org/show_bug.cgi?id=456042
  and https://bugzilla.novell.com/show_bug.cgi?id=284288#c13).
* Tue Jul  3 2007 maw@suse.de
- Add gimp-psd-overflow.patch (#284288 and CVE-2007-2949), fixing
  a buffer overflow.
* Fri May 11 2007 pgajdos@suse.cz
- removed gnome-icon-theme from BuildRequires and Requires
  [#247450]
* Mon May  7 2007 sbrabec@suse.cz
  * Updated to version gimp-2.3.16:
  * XOR color configurable as a workaround for broken drivers
  * keyboard shortcuts can assign to procedures without menu entry
  * configurable height of the preview area in data editors
  * improved file detection in TGA plug-in
  * improved brush scaling code, now also scales up
  * converted standard pixmap brushes to parametric ones
  * improved zoom tool behavior
  * D-Bus methods have a return value indicating success or failure
  * added more menu tooltips
  * procedures can request the display ID they are called from
  * depend on GTK+ >= 2.10.6
  * filename passed on the command-line can open new image
  * various optimizations, bug fixes and code cleanup
* Fri May  4 2007 sbrabec@suse.cz
- Fixed buffer overflow in sunras plugin (#270506, GNOME#433902,
  CVE-2007-2356).
* Wed Apr  4 2007 sbrabec@suse.cz
- Updated to version gimp-2.3.15:
  * Fixes, improvements, UI and API changes. See NEWS for more.
* Thu Mar  8 2007 sbrabec@suse.cz
- Removed obsolete hicolor icon symlink (#248676).
* Wed Mar  7 2007 pgajdos@suse.cz
- fixed 'warning: subscript out of range' (#231161)
- subscript-outrng.patch
* Tue Feb 27 2007 dmueller@suse.de
- adjust buildrequires: libexif -> libexif-devel
* Wed Jan  3 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Thu Sep 14 2006 sbrabec@suse.cz
- Updated to version 2.3.11:
  * Many new features, see
    /usr/share/doc/packages/gimp-unstable/NEWS for more.
  * Many bug fixes and code cleanup.
- Removed dcraw hack.
* Wed Aug 16 2006 cthiel@suse.de
- buildrequire python-gtk-devel instead of python-gtk
* Fri Jul 28 2006 sbrabec@suse.cz
- Fixed buffer overflow in xcf_load_vector (CVE-2006-3404,
  [#190901], GNOME#346742).
* Thu Jun 29 2006 nadvornik@suse.cz
- do not use deprecated libpng functions
* Wed Feb 15 2006 stbinner@suse.de
- use just "Gimp" as name, don't duplicate GenericName description
* Fri Feb 10 2006 sbrabec@suse.cz
- Updated to version 2.3.7.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan  5 2006 sbrabec@suse.cz
- Updated to version 2.3.6.
- Enabled parallel build.
* Tue Jan  3 2006 sbrabec@suse.cz
- Suggest AdobeICCProfiles.
* Mon Nov 21 2005 sbrabec@suse.cz
- Moved gimptool to -devel subpackage.
- Provide gimp symlink.
* Tue Nov  8 2005 sbrabec@suse.cz
- Build with strict aliasing.
- Fixed random return value.
* Mon Nov  7 2005 sbrabec@suse.cz
- Updated to version 2.3.5.
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Tue Sep 27 2005 sbrabec@suse.cz
- Updated to version 2.3.4.
* Mon Aug 15 2005 sbrabec@suse.cz
- Provide gimp-2.0 virtual.
* Wed Aug 10 2005 sbrabec@suse.cz
- Updated to version 2.3.3.
* Thu Aug  4 2005 sbrabec@suse.cz
- Do not self-conflict.
* Fri Jul 15 2005 sbrabec@suse.cz
- Provide and conflict with gimp.
* Tue Jul 12 2005 sbrabec@suse.cz
- Fixed MMX patch reject.
* Mon Jul 11 2005 sbrabec@suse.cz
- Created SuSE package for unstable branch.
- Updated to version 2.3.2.
- Removed unneeded static modules and .la files for modules.
* Thu Jul  7 2005 gekker@suse.de
- Fix use of uninitialized variables
- Fix to work with -D_FORTIFY_SOURCE=2
* Tue Jun  7 2005 sbrabec@suse.cz
- Fixed multiple processors option.
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Wed May 18 2005 sbrabec@suse.cz
- Updated to version 2.2.7.
* Mon May  9 2005 ro@suse.de
- use -mmmx and -msse to compile asm-code for these extensions
* Tue Apr 12 2005 sbrabec@suse.cz
- Updated to version 2.2.6.
* Wed Apr  6 2005 sbrabec@suse.cz
- Fixed incomplete array element type.
* Mon Feb 28 2005 sbrabec@suse.cz
- Updated to version 2.2.4.
* Mon Jan 24 2005 sbrabec@suse.cz
- Updated to version 2.2.3.
* Mon Jan 17 2005 sbrabec@suse.cz
- Updated to version 2.2.2.
* Thu Jan  6 2005 ro@suse.de
- postfix is in neededforbuild, so add "-sendmail" for PLUS
* Thu Jan  6 2005 sbrabec@suse.cz
- Updated to version 2.2.1.
* Tue Oct 26 2004 mmj@suse.de
- locale rename no to nb
* Wed Sep 22 2004 adrian@suse.de
- add MimeTypes line to desktop file. Gimp does support .xcf files now
* Mon Aug 30 2004 rml@suse.de
- upgrade to gimp 2.0.4 (Ximian bug #64677)
* Fri Aug 27 2004 shprasad@suse.de
- Fixes bug #63425
  Fixes GIMP Crash at the time of acquiring screen-shot and select
  extension type as png
- Partially fixes bug #63420
  Doesn't allow to crash.
* Mon Aug 16 2004 shprasad@suse.de
- Fixes bug #63006.
  Added the gtk-file-chooser dialog to Open/Save a file.
* Thu Jun 17 2004 sbrabec@suse.cz
- Updated to version 2.0.2.
* Fri Jun  4 2004 sbrabec@suse.cz
- Updated to bugfix version 2.0.1.
* Tue May 25 2004 ro@suse.de
- added libcroco to neededforbuild
* Wed May 19 2004 sbrabec@suse.cz
- German translation update from Karl Eichwalder.
* Fri May  7 2004 sbrabec@suse.cz
- Better fix (fork() instead of fail wrapper) of gimp-remote bug
  (#38512), backported from gimp-2.0.1.
  http://bugzilla.gnome.org/show_bug.cgi?id=139158
* Wed Apr  7 2004 sbrabec@suse.cz
- Work around of gimp-remote bug (#38512).
  http://bugzilla.gnome.org/show_bug.cgi?id=139158
* Wed Apr  7 2004 sbrabec@suse.cz
- Fixed WMF plugin (#38582).
* Thu Mar 25 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Wed Mar 24 2004 hhetter@suse.de
- updated to version 2.0.0 finally
* Mon Mar 22 2004 sbrabec@suse.cz
- Provide gimp2-devel.
* Mon Mar 22 2004 sbrabec@suse.cz
- Updated to version 2.0rc1.
- GIMP GNOME MIME info files linked to proper place,
- Obsolete gimp2-devel, too.
* Fri Mar  5 2004 hhetter@suse.de
- updated to 2.0pre4
- removed gimp-po-de.patch, it's upstream
- adapted tiff_no_lzw patch
* Tue Mar  2 2004 sbrabec@suse.cz
- Symlink binaries for convenience.
* Tue Mar  2 2004 sbrabec@suse.cz
- German typo fix (bug #34349).
* Fri Feb 27 2004 schwab@suse.de
- Fix broken configure check.
* Fri Feb 20 2004 sbrabec@suse.cz
- Provide and obsolete gimp2.
* Thu Feb 19 2004 sbrabec@suse.cz
- Package renamed to gimp.
* Thu Feb  5 2004 hhetter@suse.de
- updated to version 2.0pre3
- remove desktop file patch, it's called gimp2 now
* Thu Jan 29 2004 hhetter@suse.de
- updated to version 2.0pre2
* Tue Jan 27 2004 hhetter@suse.de
- updated to version 2.0pre1
- renew patch for LZW deactivation
* Mon Oct 20 2003 sbrabec@suse.cz
- Updated to version 1.3.21. Fixes screenshot bug (#32288).
- Build SVG plug-in.
- Clean-up of neededforbuild.
* Wed Oct 15 2003 ro@suse.de
- run full autoreconf
* Thu Sep 18 2003 sbrabec@suse.cz
- Do not show LZW in tiff save dialog at all (bug #29849).
* Mon Sep 15 2003 hhetter@suse.de
- name label "Gimp 1.3" in desktop file (Bug Id #30841)
* Mon Sep  8 2003 sbrabec@suse.cz
- Updated to version 1.3.20.
* Thu Aug 28 2003 sbrabec@suse.cz
- Updated to version 1.3.19.
- Enabled EXIF support.
* Sat Aug 16 2003 adrian@suse.de
- install desktop file
* Thu Aug 14 2003 sbrabec@suse.cz
- Updated to version 1.3.18.
* Mon Aug  4 2003 sbrabec@suse.cz
- Updated to version 1.3.17.
* Fri Jul 25 2003 hhetter@suse.de
- fix build
* Thu Jun 26 2003 sbrabec@suse.cz
- Updated to version 1.3.15.
- Used system libgimpprint.
* Thu Jun 19 2003 ro@suse.de
- added directories to filelist
* Tue Jun 10 2003 sbrabec@suse.cz
- Initial SuSE version of GTK2 port.
